@@ -1,7 +1,8 @@
 from lightning.types.base import Base
 from lightning.types.decorators import viztype
 from lightning.types.utils import array_to_lines, vecs_to_points, \
-    mat_to_links, array_to_im, add_property, mat_to_array, list_to_regions, check_colormap
+    parse_links, array_to_im, add_property, mat_to_array, list_to_regions, \
+    check_colormap, parse_nodes
 
 
 @viztype
@@ -18,7 +19,7 @@ class Scatter(Base):
     _name = 'scatter'
 
     @staticmethod
-    def clean(x, y, color=None, label=None, size=None, alpha=None, xaxis=None, yaxis=None):
+    def clean(x, y, color=None, label=None, value=None, colormap=None, size=None, alpha=None, xaxis=None, yaxis=None):
         """
         Plot two-dimensional data as points.
 
@@ -35,6 +36,12 @@ class Scatter(Base):
         label : array-like, optional, singleton or (n,)
             Single integer or array to set colors via groups
 
+        value : array-like, optional, singleton or (n,)
+            Values to set node colors via a linear scale
+
+        colormap : string
+            Specification of color map, only colorbrewer types supported
+
         size : array-like, optional, singleton or (n,)
             Single size or array to set point sizes
 
@@ -53,6 +60,8 @@ class Scatter(Base):
 
         outdict = add_property(outdict, color, 'color')
         outdict = add_property(outdict, label, 'label')
+        outdict = add_property(outdict, value, 'value')
+        outdict = add_property(outdict, colormap, 'colormap')
         outdict = add_property(outdict, size, 'size')
         outdict = add_property(outdict, alpha, 'alpha')
         outdict = add_property(outdict, xaxis, 'xaxis')
@@ -60,6 +69,26 @@ class Scatter(Base):
 
         return outdict
 
+    def selected(self):
+        """
+        Selected points from scatter plot as indices
+        """
+        user_data = self.get_user_data()['settings']
+        if 'selected' in user_data.keys():
+            return user_data['selected']
+        else:
+            return []
+
+    def points(self):
+        """
+        Selected points from scatter plot as x,y coordinates
+        """
+        user_data = self.get_user_data()['settings']
+        if 'x' in user_data.keys() and 'y' in user_data.keys():
+            return user_data['x'], user_data['y']
+        else:
+            return []
+
 @viztype
 class Matrix(Base):
 
@@ -84,9 +113,6 @@ class Matrix(Base):
         matrix = mat_to_array(matrix)
         outdict = {'matrix': matrix}
 
-        if colormap:
-            check_colormap(colormap)
-
         outdict = add_property(outdict, colormap, 'colormap')
 
         return outdict
@@ -97,7 +123,7 @@ class Adjacency(Base):
     _name = 'adjacency'
 
     @staticmethod
-    def clean(matrix, label=None):
+    def clean(conn, label=None):
 
         """
         Visualize a sparse adjacency matrix.
@@ -106,15 +132,18 @@ class Adjacency(Base):
 
         Parameters
         ----------
-        matrix : array-like
-            Two-dimensional array of matrix data
+       conn : array-like, (n,n) or (n,3) or (n,2)
+            Input connectivity data as either a matrix or a list of links.
+            Matrix can be binary or continuous valued. Links should contain
+            either 2 elements per link (source, target),
+            or 3 elements (source, target, value).
 
-        colormap : string
-            Specification of color map, only colorbrewer types supported
+        label : array-like, optional, singleton or (n,)
+            Single integer or array to set colors via groups
         """
+        links = parse_links(conn)
+        nodes = parse_nodes(conn)
 
-        links = mat_to_links(matrix)
-        nodes = list(range(0, matrix.shape[0]))
         outdict = {'links': links, 'nodes': nodes}
 
         outdict = add_property(outdict, label, 'label')
@@ -162,16 +191,13 @@ class Line(Base):
         size : array-like, optional, singleton or (n,)
             Single size or array to set line thickness
 
-        size : array-like, optional, singleton or (n,)
-            Single size or array to set line thickness
-
         xaxis : str, optional, default = None
             Label for x-axis
 
         yaxis : str, optional, default = None
             Label for y-axis
         """
-        
+
         series = array_to_lines(series)
         outdict = {'series': series}
 
@@ -231,17 +257,19 @@ class Force(Base):
     _func = 'force'
 
     @staticmethod
-    def clean(matrix, color=None, label=None, size=None):
+    def clean(conn, color=None, label=None, value=None, colormap=None, size=None):
         """
-        Create a force-directed network from a connectivity matrix.
+        Create a force-directed network from connectivity.
 
         .. image:: force.png
 
         Parameters
         ----------
-        matrix : array-like, (n,n)
-            Input data with connectivity matrix. Can be binary or continuous-valued
-            for weighted edges.
+        conn : array-like, (n,n) or (n,3) or (n,2)
+            Input connectivity data as either a matrix or a list of links.
+            Matrix can be binary or continuous valued. Links should contain
+            either 2 elements per link (source, target),
+            or 3 elements (source, target, value).
 
         color : array-like, optional, singleton or (n,3)
             Single rgb value or array to set node colors
@@ -249,21 +277,39 @@ class Force(Base):
         label : array-like, optional, singleton or (n,)
             Single integer or array to set node colors via group labels
 
+        value : array-like, optional, singleton or (n,)
+            Values to set node colors via a linear scale
+
+        colormap : string
+            Specification of color map, only colorbrewer types supported
+
         size : array-like, optional, singleton or (n,)
             Single size or array to set node sizes
         """
 
-        links = mat_to_links(matrix)
-        nodes = list(range(0, matrix.shape[0]))
+        links = parse_links(conn)
+        nodes = parse_nodes(conn)
 
         outdict = {'links': links, 'nodes': nodes}
 
         outdict = add_property(outdict, color, 'color')
         outdict = add_property(outdict, label, 'label')
+        outdict = add_property(outdict, value, 'value')
+        outdict = add_property(outdict, colormap, 'colormap')
         outdict = add_property(outdict, size, 'size')
 
         return outdict
 
+    def selected(self):
+        """
+        Selected points from force plot
+        """
+        user_data = self.get_user_data()['settings']
+        if 'selected' in user_data.keys():
+            return user_data['selected']
+        else:
+            return []
+
 @viztype
 class Graph(Base):
 
@@ -271,9 +317,9 @@ class Graph(Base):
     _func = 'graph'
 
     @staticmethod
-    def clean(x, y, matrix, color=None, label=None, size=None, imagedata=None):
+    def clean(x, y, conn, color=None, label=None, value=None, colormap=None, size=None, imagedata=None):
         """
-        Create a node-link graph from spatial points and their connectivity matrix.
+        Create a node-link graph from spatial points and their connectivity.
 
         .. image:: graph.png
 
@@ -282,9 +328,11 @@ class Graph(Base):
         x,y : array-like, each (n,)
             Input data for nodes (x,y coordinates)
 
-        matrix : array, (n,n)
-            Input data with connectivity matrix. Can be binary or continuous-valued
-            (for weighted edges).
+        conn : array-like, (n,n) or (n,3) or (n,2)
+            Input connectivity data as either a matrix or a list of links.
+            Matrix can be binary or continuous valued. Links should contain
+            either 2 elements per link (source, target),
+            or 3 elements (source, target, value).
 
         color : array-like, optional, singleton or (n,) or (n,3)
             Single rgb value or array to set node colors
@@ -292,17 +340,25 @@ class Graph(Base):
         label : array-like, optional, singleton or (n,)
             Single integer or array to set node colors via group labels
 
+        value : array-like, optional, singleton or (n,)
+            Values to set node colors via a linear scale
+
+        colormap : string
+            Specification of color map, only colorbrewer types supported
+
         size : array-like, optional, singleton or (n,)
             Single size or array to set node sizes
         """
 
-        links = mat_to_links(matrix)
+        links = parse_links(conn)
         nodes = vecs_to_points(x, y)
 
         outdict = {'links': links, 'nodes': nodes}
 
         outdict = add_property(outdict, color, 'color')
         outdict = add_property(outdict, label, 'label')
+        outdict = add_property(outdict, value, 'value')
+        outdict = add_property(outdict, colormap, 'colormap')
         outdict = add_property(outdict, size, 'size')
 
         if imagedata is not None:
@@ -319,9 +375,9 @@ class GraphBundled(Base):
     _func = 'graphbundled'
 
     @staticmethod
-    def clean(x, y, matrix, color=None, label=None, size=None, imagedata=None):
+    def clean(x, y, conn, color=None, label=None, value=None, colormap=None, size=None, imagedata=None):
         """
-        Create a node-link graph with bundled edges.
+        Create a node-link graph with bundled edges from spatial points and their connectivity.
 
         .. image:: graphbundled.png
 
@@ -330,9 +386,11 @@ class GraphBundled(Base):
         x,y : array-like, each (n,)
             Input data for nodes (x,y coordinates)
 
-        matrix : array, (n,n)
-            Input data with connectivity matrix. Can be binary or continuous-valued
-            (for weighted edges).
+        conn : array-like, (n,n) or (n,3) or (n,2)
+            Input connectivity data as either a matrix or a list of links.
+            Matrix can be binary or continuous valued. Links should contain
+            either 2 elements per link (source, target),
+            or 3 elements (source, target, value).
 
         color : array-like, optional, singleton or (n,) or (n,3)
             Single rgb value or array to set node colors
@@ -340,17 +398,24 @@ class GraphBundled(Base):
         label : array-like, optional, singleton or (n,)
             Single integer or array to set node colors via group labels
 
+        value : array-like, optional, singleton or (n,)
+            Values to set node colors via a linear scale
+
+        colormap : string
+            Specification of color map, only colorbrewer types supported
+
         size : array-like, optional, singleton or (n,)
             Single size or array to set node sizes
         """
-
+        links, _ = parse_links(conn)
         points = vecs_to_points(x, y)
-        links = mat_to_links(matrix)
 
         outdict = {'links': links, 'nodes': points}
 
         outdict = add_property(outdict, color, 'color')
         outdict = add_property(outdict, label, 'label')
+        outdict = add_property(outdict, value, 'value')
+        outdict = add_property(outdict, colormap, 'colormap')
         outdict = add_property(outdict, size, 'size')
 
         if imagedata is not None:
