@@ -1,5 +1,5 @@
 from numpy import asarray, array, ndarray, vstack, newaxis, nonzero, concatenate, \
-    transpose, atleast_2d, size, isscalar, meshgrid, where, zeros
+    transpose, atleast_2d, size, isscalar, meshgrid, where, zeros, ones
 from matplotlib.path import Path
 
 
@@ -24,6 +24,7 @@ def check_property(prop, name, **kwargs):
         'size': check_size,
         'index': check_index,
         'coordinates': check_coordinates,
+        'colormap': check_colormap
     }
 
     if name in checkers:
@@ -70,12 +71,14 @@ def check_colormap(cmap):
     """
     Check if cmap is one of the colorbrewer maps
     """
-    names = set(['BrBG', 'PiYG', 'PRGn', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu', 'RdYlGn', 'Spectral', 'Blues', 'BuGn', 'BuPu',
-             'GnBu', 'Greens', 'Greys', 'Oranges', 'OrRd', 'PuBu', 'PuBuGn', 'PuRd', 'Purples', 'RdPu', 'Reds',
-             'YlGn', 'YlGnBu', 'YlOrBr', 'YlOrRd', 'Accent', 'Dark2',
-             'Paired', 'Pastel1', 'Pastel2', 'Set1', 'Set2', 'Set3'])
+    names = set(['BrBG', 'PiYG', 'PRGn', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu', 'RdYlGn', 'Spectral',
+                 'Blues', 'BuGn', 'BuPu', 'GnBu', 'Greens', 'Greys', 'Oranges', 'OrRd', 'PuBu',
+                 'PuBuGn', 'PuRd', 'Purples', 'RdPu', 'Reds', 'YlGn', 'YlGnBu', 'YlOrBr', 'YlOrRd',
+                 'Accent', 'Dark2', 'Paired', 'Pastel1', 'Pastel2', 'Set1', 'Set2', 'Set3', 'Lightning'])
     if cmap not in names:
         raise Exception("Invalid cmap '%s',  must be one of %s" % (cmap, names))
+    else:
+        return cmap
 
 
 def check_size(s):
@@ -168,6 +171,7 @@ def vecs_to_points_three(x, y, z):
 
     return points
 
+
 def mat_to_array(mat):
 
     mat = asarray(mat)
@@ -192,6 +196,37 @@ def mat_to_links(mat):
     return links
 
 
+def parse_nodes(data):
+
+    data = asarray(data)
+
+    if data.shape[0] == data.shape[1]:
+        nodes = list(range(0, len(data)))
+
+    else:
+        nodes = list(range(0, int(max(max(data[:, 0]), max(data[:, 1])) + 1)))
+
+    return nodes
+
+
+def parse_links(data):
+
+    data = asarray(data)
+
+    if data.shape[0] == data.shape[1]:
+        links = mat_to_links(data)
+
+    else:
+        if len(data[0]) == 2:
+            links = concatenate((data, ones((len(data), 1))), axis=1)
+        elif len(data[0]) == 3:
+            links = data
+        else:
+            raise ValueError("Too many entries per link, must be 2 or 3, got %g" % len(data[0]))
+
+    return links
+
+
 def array_to_im(im):
 
     from matplotlib.pyplot import imsave
